KeyedPoolMessage

Enum KeyedPoolMessage 

pub enum KeyedPoolMessage<A, D, K, J, R>
where A: Address, D: Behavior<Addr = A, Msg = PoolResponse<J, R, A>>,
{ Submit { key: K, job: JobId, payload: J, reply_to: Recipient<D>, }, Completed { worker: <D::Addr as Address>::Nonce, assignment: AssignmentId, result: R, }, Rebalance { key: K, worker: <D::Addr as Address>::Nonce, }, }
Messages accepted by a key-persistent pool coordinator.

Rebalance is the only input that can change an established key binding. It affects later submissions; jobs already accepted retain their selected stable worker slot.

Variants



Submit

Fields

key: K
job: JobId
payload: J
reply_to: Recipient<D>


Completed

Fields

worker: <D::Addr as Address>::Nonce
assignment: AssignmentId
result: R


Rebalance

Fields

key: K
worker: <D::Addr as Address>::Nonce