pub enum PoolInterruption<A: Address> {
WorkerStopped {
worker: A::Nonce,
outcome: Result<Exit<A>, Crash>,
},
NoRecoverableWorkers,
AffinityRetired {
worker: A::Nonce,
reason: WorkerRetirement,
},
}Expand description
Why an accepted assignment ended without a worker completion.
Variants
WorkerStopped
NoRecoverableWorkers
AffinityRetired
The job’s selected stable slot retired while the job was queued.