pub enum PoolRejection {
BacklogFull,
AffinityUnavailable,
}Expand description
Why a submitted job was not accepted by the pool.
Variants
BacklogFull
The key’s selected stable slot is unknown or permanently retired.