Active

Struct Active 

pub struct Active<B: Behavior> { /* private fields */ }
A behavior whose initialization fold has completed exactly once.

Active<B> does not implement Behavior, so initialization cannot be repeated through the public API:

use behavior::{Behavior, Compose, Machine, MailAddr, Move, Never};

let definition: Compose<Machine<MailAddr, (), u8, (), Never>> =
    Compose::new(Machine::new((), (), |_, _, _| Ok(Move::Stay)));
let active = definition.initialize().unwrap().behavior;
active.initialize();

Implementations

Source

impl<B: Behavior> Active<B>

pub fn base(&self) -> &B::Base
where B: BehaviorBase,

pub fn stashed(&self) -> usize
where B: StashStatus,

pub fn transition(&mut self, event: B::Event) -> BehaviorActed<B>

Fold exactly one event after initialization.

pub fn receive(&mut self, from: B::Addr, message: B::Msg) -> BehaviorActed<B>

Fold one user communication after initialization.

pub fn on<Input>(&mut self, input: Input) -> BehaviorActed<B>
where B::Event: EventInput<Input>,

Fold one statically supported semantic input after initialization.