pub struct ActiveTurn { /* private fields */ }Expand description
Crate-minted capability for defining one active mailbox fold.
Values can only be issued by an initialized crate::Active behavior or
by a concrete core wrapper delegating the same active turn inward.