EventInput

Trait EventInput 

pub trait EventInput<Input>: Sized {
    // Required method
    fn inject(input: Input) -> Self;
}
A statically proven injection of one semantic input into a concrete event sum.

Implementations must select exactly one constructor and preserve input unchanged. Absence of an implementation means that the protocol does not accept that input.

Required Methods

fn inject(input: Input) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<A, M> EventInput<User<A, M>> for User<A, M>