RouteInput

Trait RouteInput 

pub trait RouteInput<Input>: Sized {
    // Required method
    fn route(input: Input) -> Result<Self, Input>;
}
Attempt to route one input through a nested event product.

Unlike EventInput, this is not an acceptance capability. It is the lossless routing operation used by an outer wrapper when it does not own an input itself. Rejection returns the original input unchanged.

Required Methods

fn route(input: Input) -> Result<Self, Input>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<A, M, Input> RouteInput<Input> for User<A, M>

Source

impl<E: UserEvent> RouteInput<ChildStopped<<E as UserEvent>::Addr>> for ProxyEvent<E>

Source

impl<E: UserEvent> RouteInput<ChildStopped<<E as UserEvent>::Addr>> for SupervisionEvent<E>

Source

impl<E: UserEvent> RouteInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for ProxyEvent<E>

Source

impl<E: UserEvent> RouteInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for SupervisionEvent<E>

Source

impl<E: UserEvent> RouteInput<PeerStopped<<E as UserEvent>::Addr>> for WatchEvent<E>

Source

impl<E: UserEvent> RouteInput<ShutdownRequested> for ShutdownProtocol<E>

Source

impl<E: UserEvent> RouteInput<TimerElapsed> for TimedEvent<E>

Source

impl<E: UserEvent> RouteInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for SupervisionEvent<E>

Source

impl<E: UserEvent> RouteInput<WorkerStopped<<E as UserEvent>::Addr>> for SupervisionEvent<E>

Source

impl<E> RouteInput<ChildStopped<<E as UserEvent>::Addr>> for ShutdownProtocol<E>

Source

impl<E> RouteInput<ChildStopped<<E as UserEvent>::Addr>> for TimedEvent<E>

Source

impl<E> RouteInput<ChildStopped<<E as UserEvent>::Addr>> for WatchEvent<E>

Source

impl<E> RouteInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for ShutdownProtocol<E>

Source

impl<E> RouteInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for TimedEvent<E>

Source

impl<E> RouteInput<CreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for WatchEvent<E>

Source

impl<E> RouteInput<PeerStopped<<E as UserEvent>::Addr>> for ProxyEvent<E>

Source

impl<E> RouteInput<PeerStopped<<E as UserEvent>::Addr>> for ShutdownProtocol<E>

Source

impl<E> RouteInput<PeerStopped<<E as UserEvent>::Addr>> for SupervisionEvent<E>

Source

impl<E> RouteInput<PeerStopped<<E as UserEvent>::Addr>> for TimedEvent<E>

Source

impl<E> RouteInput<ShutdownRequested> for ProxyEvent<E>

Source

impl<E> RouteInput<ShutdownRequested> for SupervisionEvent<E>

Source

impl<E> RouteInput<ShutdownRequested> for TimedEvent<E>

Source

impl<E> RouteInput<ShutdownRequested> for WatchEvent<E>

Source

impl<E> RouteInput<TimerElapsed> for ProxyEvent<E>

Source

impl<E> RouteInput<TimerElapsed> for ShutdownProtocol<E>

Source

impl<E> RouteInput<TimerElapsed> for SupervisionEvent<E>

Source

impl<E> RouteInput<TimerElapsed> for WatchEvent<E>

Source

impl<E> RouteInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for ProxyEvent<E>

Source

impl<E> RouteInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for ShutdownProtocol<E>

Source

impl<E> RouteInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for TimedEvent<E>

Source

impl<E> RouteInput<WorkerCreationResolved<<<E as UserEvent>::Addr as Address>::Nonce>> for WatchEvent<E>

Source

impl<E> RouteInput<WorkerStopped<<E as UserEvent>::Addr>> for ProxyEvent<E>

Source

impl<E> RouteInput<WorkerStopped<<E as UserEvent>::Addr>> for ShutdownProtocol<E>

Source

impl<E> RouteInput<WorkerStopped<<E as UserEvent>::Addr>> for TimedEvent<E>

Source

impl<E> RouteInput<WorkerStopped<<E as UserEvent>::Addr>> for WatchEvent<E>