pub struct Supervising<B: Behavior, C: Behavior<Ph = Never, Addr = B::Addr>> { /* private fields */ }Implementations
Sourceimpl<B, C> Supervising<B, C>
impl<B, C> Supervising<B, C>
Sourcepub fn new(
inner: B,
nonces: fn(usize) -> <B::Addr as Address>::Nonce,
count: usize,
build: fn(usize) -> C,
strategy: Strategy,
policy: RestartPolicy,
max_restarts: u32,
window: Duration,
) -> Self
pub fn new( inner: B, nonces: fn(usize) -> <B::Addr as Address>::Nonce, count: usize, build: fn(usize) -> C, strategy: Strategy, policy: RestartPolicy, max_restarts: u32, window: Duration, ) -> Self
Construct the concrete supervisor behavior hidden by Spec.
Panics
Panics only if a fleet index cannot be represented by u64.
pub fn with_strategy(self, strategy: Strategy) -> Self
pub fn with_policy(self, policy: RestartPolicy) -> Self
pub fn with_budget(self, max: u32, window: Duration) -> Self
Sourcepub fn is_alive(&self, nonce: <B::Addr as Address>::Nonce) -> bool
pub fn is_alive(&self, nonce: <B::Addr as Address>::Nonce) -> bool
Report whether a known supervised proxy is alive.
Panics
Panics when nonce is not part of this supervisor topology.
pub fn child_count(&self) -> usize
pub fn restarts_in_window(&self) -> usize