pub trait EventInput<Input>: Sized {
// Required method
fn inject(input: Input) -> Self;
}Expand description
A statically proven injection of one semantic input into a concrete event sum.
Implementations must select exactly one constructor and preserve input
unchanged. Absence of an implementation means that the protocol does not
accept that input.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".