pub trait RouteInput<Input>: Sized {
// Required method
fn route(input: Input) -> Result<Self, Input>;
}Expand description
Attempt to route one input through a nested event product.
Unlike EventInput, this is not an acceptance capability. It is the
lossless routing operation used by an outer wrapper when it does not own an
input itself. Rejection returns the original input unchanged.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".