SendInput

Trait SendInput 

pub trait SendInput<Input, Path> {
    // Required method
    fn emit(&mut self, input: Input);
}
Static evidence that a send product contains one request lane.

Implementations append the input exactly once to that lane and leave every other lane unchanged. Path distinguishes repeated request types without erasing their position or choosing a lane at runtime.

Required Methods

fn emit(&mut self, input: Input)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> SendInput<T, Own> for Vec<T>

Source

fn emit(&mut self, input: T)

Implementors

Source

impl<A, Sends, C, Input, Path> SendInput<Input, Inner<Path>> for SupervisorSends<A, Sends, C>
where A: Address, C: Behavior<Addr = A>, Sends: SendInput<Input, Path>,

Source

impl<A, Sends, C> SendInput<Delivery<A, ProxyCommand<C>>, Own> for SupervisorSends<A, Sends, C>
where A: Address, C: Behavior<Addr = A>,

Source

impl<A, Sends, C> SendInput<ObserveChild<<A as Address>::Nonce>, Own> for SupervisorSends<A, Sends, C>
where A: Address, C: Behavior<Addr = A>,

Source

impl<A: Address, M> SendInput<Delivery<A, M>, Own> for ProxySends<A, M>

Source

impl<A: Address, M> SendInput<ObserveChild<<A as Address>::Nonce>, Own> for ProxySends<A, M>

Source

impl<A: Address, M> SendInput<ObserveCreation<<A as Address>::Nonce>, Own> for ProxySends<A, M>

Source

impl<A: Address, M> SendInput<ReportWorkerCreationResolved<<A as Address>::Nonce>, Own> for ProxySends<A, M>

Source

impl<A: Address, M> SendInput<ReportWorkerStopped<A>, Own> for ProxySends<A, M>

Source

impl<A: Address, Sends, Input, Path> SendInput<Input, Inner<Path>> for WatchSends<A, Sends>
where Sends: SendInput<Input, Path>,

Source

impl<A: Address, Sends> SendInput<ObservePeer<A>, Own> for WatchSends<A, Sends>

Source

impl<M> SendInput<M, Own> for ServiceSends<M>

Source

impl<Sends, Input, Path> SendInput<Input, Inner<Path>> for DeadlineSends<Sends>
where Sends: SendInput<Input, Path>,

Source

impl<Sends, Input, Path> SendInput<Input, Inner<Path>> for ReceiveTimeoutSends<Sends>
where Sends: SendInput<Input, Path>,

Source

impl<Sends> SendInput<ScheduleAfter, Own> for ReceiveTimeoutSends<Sends>

Source

impl<Sends> SendInput<ScheduleAt, Own> for DeadlineSends<Sends>